@@ -183,10 +183,11 @@ struct Context {
     void bind(Server *server);
     void bind(coroutine::Socket *socket);
     void copy(Context *ctx);
-    bool parse_form_data(const char *boundary_str, int boundary_len);
+    bool init_multipart_parser(const char *boundary_str, int boundary_len);
     bool get_form_data_boundary(
         const char *at, size_t length, size_t offset, char **out_boundary_str, int *out_boundary_len);
     size_t parse(const char *data, size_t length);
+    bool parse_multipart_data(const char *at, size_t length);
     bool set_header(const char *, size_t, zval *, bool);
     bool set_header(const char *, size_t, const char *, size_t, bool);
     void end(zval *zdata, zval *return_value);
