@@ -60,7 +60,7 @@ bool PHPCoroutine::interrupt_thread_running = false;
 
 extern void php_swoole_load_library();
 
-static zend_bool *zend_vm_interrupt = nullptr;
+static zend_atomic_bool *zend_vm_interrupt = nullptr;
 static user_opcode_handler_t ori_exit_handler = nullptr;
 static user_opcode_handler_t ori_begin_silence_handler = nullptr;
 static user_opcode_handler_t ori_end_silence_handler = nullptr;
@@ -329,17 +329,15 @@ void PHPCoroutine::error_cb(int type,
     }
 }
 
-void PHPCoroutine::catch_exception(zend_object *exception) {
-    // TODO: exceptions will only cause the coroutine to exit
-    if (sw_reactor()) {
-        sw_reactor()->running = false;
-        sw_reactor()->bailout = true;
-    }
-    Coroutine::bailout([exception]() {
+void PHPCoroutine::catch_exception() {
+    if (UNEXPECTED(EG(exception))) {
         zend_error_cb = orig_error_function;
-        zend_exception_error(exception, E_ERROR);
+        // the exception error messages MUST be output on the current coroutine stack
+        zend_exception_error(EG(exception), E_ERROR);
+#if PHP_VERSION_ID >= 80000
         zend_bailout();
-    });
+#endif
+    }
 }
 
 void PHPCoroutine::activate() {
@@ -448,7 +446,7 @@ void PHPCoroutine::interrupt_thread_start() {
     interrupt_thread = std::thread([]() {
         swoole_signal_block_all();
         while (interrupt_thread_running) {
-            *zend_vm_interrupt = 1;
+            zend_atomic_bool_store(zend_vm_interrupt, 1);
             std::this_thread::sleep_for(std::chrono::milliseconds(MAX_EXEC_MSEC / 2));
         }
     });
@@ -839,15 +837,18 @@ void PHPCoroutine::main_func(void *arg) {
             OBJ_RELEASE(fci_cache.object);
         }
         zval_ptr_dtor(retval);
-
-        if (UNEXPECTED(EG(exception))) {
-            catch_exception(EG(exception));
-        }
-
+        catch_exception();
 #ifdef SW_CORO_SUPPORT_BAILOUT
     }
     zend_catch {
-        catch_exception(EG(exception));
+        catch_exception();
+        Coroutine::bailout([]() {
+            if (sw_reactor()) {
+                sw_reactor()->running = false;
+                sw_reactor()->bailout = true;
+            }
+            zend_bailout();
+        });
     }
     zend_end_try();
 #endif
