@@ -10,7 +10,7 @@
  | to obtain it through the world-wide-web, please send a note to       |
  | license@swoole.com so we can mail you a copy immediately.            |
  +----------------------------------------------------------------------+
- | Author: Tianfeng Han  <mikan.tenny@gmail.com>                        |
+ | Author: Tianfeng Han  <rango@swoole.com>                             |
  | Author: Twosee  <twose@qq.com>                                       |
  | Author: Fang  <coooold@live.com>                                     |
  | Author: Yuanyi   Zhi  <syyuanyizhi@163.com>                          |
@@ -149,20 +149,20 @@ class HttpClient {
     bool send();
     void reset();
 
-    static inline void add_headers(String *buf, const char *key, size_t key_len, const char *data, size_t data_len) {
+    static void add_headers(String *buf, const char *key, size_t key_len, const char *data, size_t data_len) {
         buf->append(key, key_len);
         buf->append(ZEND_STRL(": "));
         buf->append(data, data_len);
         buf->append(ZEND_STRL("\r\n"));
     }
 
-    static inline void add_content_length(String *buf, int length) {
-        char content_length_str[32];
-        int n = snprintf(SW_STRS(content_length_str), "Content-Length: %d\r\n\r\n", length);
+    static void add_content_length(String *buf, size_t length) {
+        char content_length_str[64];
+        size_t n = sw_snprintf(SW_STRS(content_length_str), "Content-Length: %zu\r\n\r\n", length);
         buf->append(content_length_str, n);
     }
 
-    static inline void create_token(int length, char *buf) {
+    static void create_token(int length, char *buf) {
         char characters[] = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!\"§$%&/()=[]{}";
         int i;
         assert(length < 1024);
