@@ -90,18 +90,31 @@ struct _php_curl_send_headers {
     zend_string *str;
 };
 
+#if PHP_VERSION_ID >= 80100
+struct _php_curl_free {
+    zend_llist post;
+    zend_llist stream;
+#if LIBCURL_VERSION_NUM < 0x073800 /* 7.56.0 */
+    zend_llist buffers;
+#endif
+    HashTable *slist;
+};
+#else
 struct _php_curl_free {
     zend_llist str;
     zend_llist post;
     zend_llist stream;
     HashTable *slist;
 };
-
-using CurlCallback = std::function<bool(void)>;
+#endif
 
 typedef struct {
     CURL *cp;
+#if PHP_VERSION_ID >= 80100
+    php_curl_handlers handlers;
+#else
     php_curl_handlers *handlers;
+#endif
 #if PHP_VERSION_ID < 80000
     zend_resource *res;
 #endif
@@ -174,6 +187,22 @@ void swoole_curl_multi_cleanup_list(void *data);
 void swoole_curl_verify_handlers(php_curl *ch, int reporterror);
 void swoole_setup_easy_copy_handlers(php_curl *ch, php_curl *source);
 
+#if PHP_VERSION_ID >= 80100
+static inline php_curl_handlers *curl_handlers(php_curl *ch) {
+    return &ch->handlers;
+}
+#else
+static inline php_curl_handlers *curl_handlers(php_curl *ch) {
+    return ch->handlers;
+}
+#endif
+
+#if PHP_VERSION_ID >= 80200
+typedef zend_result curl_result_t;
+#else
+typedef int curl_result_t;
+#endif
+
 #if PHP_VERSION_ID >= 80000
 static inline php_curl *curl_from_obj(zend_object *obj) {
     return (php_curl *) ((char *) (obj) -XtOffsetOf(php_curl, std));
@@ -187,7 +216,7 @@ static inline php_curlsh *curl_share_from_obj(zend_object *obj) {
 
 #define Z_CURL_SHARE_P(zv) curl_share_from_obj(Z_OBJ_P(zv))
 void curl_multi_register_class(const zend_function_entry *method_entries);
-int swoole_curl_cast_object(zend_object *obj, zval *result, int type);
+curl_result_t swoole_curl_cast_object(zend_object *obj, zval *result, int type);
 #else
 #define Z_CURL_P(zv) swoole_curl_get_handle(zv)
 #endif /* PHP8 end */
